<?php
// Disallow direct access
if(!defined('WPINC')) exit;

/**
 * Extends ZenCache to allow it to work correctly with Aelia Internationalisation
 * solutions.
 *
 * @author Aelia <support@aelia.co>
 */
class Aelia_Internationalisation_ZenCache {
	const VERSION = '1.0.1.160401';

	// @var Aelia_Internationalisation_ZenCache The class instance
	protected $instance;

	// @var string The cache key that ZenCache should use to retrieve the cached content
	protected $cache_key;

	// @var array A list of the cookies that should be processed to build the cache key
	protected function expected_cookies() {
		return array(
			'aelia_cs_selected_currency',
			'aelia_customer_country',
			'aelia_customer_state',
			'aelia_billing_country',
			'aelia_tax_exempt',
		);
	}

	/**
	 * Returns the cache key to be used by ZenCache. The key takes into account
	 * elements such as the selected currency, customer's country, customer's
	 * State/county, and so on.
	 *
	 * @return string
	 */
	protected function get_cache_key() {
		$cache_key = '';
		foreach($this->expected_cookies() as $cookie_name) {
			if(!empty($_COOKIE[$cookie_name])) {
				$cache_key .= $_COOKIE[$cookie_name];
			}
		}
		return $cache_key;
	}

	/**
	 * Class constructor.
	 */
	public function __construct() {
		/**
		 * @var $ac \zencache\advanced_cache Object instance.
		 */
		$advanced_cache = $GLOBALS['zencache__advanced_cache']; // See: `advanced-cache.php`.
		if(empty($advanced_cache)) {
			return;
		}

		$this->cache_key = $this->get_cache_key();

		// If one or more cookies are set by the Aelia internationalisation plugins,
		// enable the callback that will set the cache key
		if(!empty($this->cache_key)) {
			// This callback will dynamically modify the version salt, allowing to
			// store multiple cached versions of pages
			$advanced_cache->add_filter(get_class($advanced_cache).'__version_salt',
																	array($this, 'aelia_salt_shaker'));
		}
		else {
			// Debug
			//var_dump("NO COOKIES FOUND. ASSUMING FIRST TIME VISITOR AND DISABLING CACHE");
			$_SERVER['ZENCACHE_ALLOWED'] = false;
			if(!defined('DONOTCACHEPAGE')) {
				define('DONOTCACHEPAGE', true);
			}
		}
	}

	/**
	 * Initialises the plugin.
	 */
	public static function init() {
		self:$instance = new self();
	}

	/**
	 * Extends the standard cache key with one that includes additional arguments,
	 * such as customer's currency, country, state, etc.
	 *
	 * @param string $version_salt The original cache key passed by ZenCache.
	 * @return string The updated cache key.
	 */
	public function aelia_salt_shaker($version_salt) {
		$version_salt .= (string)$this->cache_key;
		// Debug
		//var_dump("CACHE KEY FOR PAGE: {$version_salt}");
		return $version_salt;
	}
}

Aelia_Internationalisation_ZenCache::init();
